Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(309)

Unified Diff: net/android/http_auth_negotiate_android.h

Issue 1414313002: Allow dynamic updating of authentication policies (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Respond to cbentzel@'s comments. Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/chrome/browser/ios_chrome_io_thread.cc ('k') | net/android/http_auth_negotiate_android.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/android/http_auth_negotiate_android.h
diff --git a/net/android/http_auth_negotiate_android.h b/net/android/http_auth_negotiate_android.h
index e9132e2a3d783b0bf7833d0c5711ccb6b6730c0b..1b337261fcd3687da189f1bf5cd475311cf95b62 100644
--- a/net/android/http_auth_negotiate_android.h
+++ b/net/android/http_auth_negotiate_android.h
@@ -19,6 +19,7 @@
namespace net {
class HttpAuthChallengeTokenizer;
+class HttpAuthPreferences;
namespace android {
@@ -58,9 +59,10 @@ class NET_EXPORT_PRIVATE JavaNegotiateResultWrapper {
// for the full details.
class NET_EXPORT_PRIVATE HttpAuthNegotiateAndroid {
public:
- // Creates an object for one negotiation session. |account_type| is the
- // Android account type, used by Android to find the correct authenticator.
- explicit HttpAuthNegotiateAndroid(const std::string& account_type);
+ // Creates an object for one negotiation session. |prefs| are the
+ // authentication preferences. In particular they include the Android account
+ // type, which is used to connect to the correct Android Authenticator.
+ explicit HttpAuthNegotiateAndroid(const HttpAuthPreferences* prefs);
~HttpAuthNegotiateAndroid();
// Register the JNI for this class.
@@ -116,7 +118,7 @@ class NET_EXPORT_PRIVATE HttpAuthNegotiateAndroid {
private:
void SetResultInternal(int result, const std::string& token);
- std::string account_type_;
+ const HttpAuthPreferences* prefs_;
bool can_delegate_;
bool first_challenge_;
std::string server_auth_token_;
« no previous file with comments | « ios/chrome/browser/ios_chrome_io_thread.cc ('k') | net/android/http_auth_negotiate_android.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698